pub struct BufferTooSmallError(pub Option<usize>);Expand description
The output buffer is too small.
It contains the size that the buffer needs to be for the call to succeed, if known.
Tuple Fields
0: Option<usize>Implementations