SendCtx

Struct SendCtx 

pub struct SendCtx<K, F, A>
where K: HpkeKem, F: HpkeKdf, A: HpkeAead,
{ /* private fields */ }
An encryption context that encrypts messages for a particular recipient.

Implementations

Source

impl<K, F, A> SendCtx<K, F, A>
where K: HpkeKem, F: HpkeKdf, A: HpkeAead,

pub const OVERHEAD: usize = SealCtx<A>::OVERHEAD

The size in bytes of the overhead added to the plaintext.

pub fn seal( &mut self, dst: &mut [u8], plaintext: &[u8], additional_data: &[u8], ) -> Result<Seq, HpkeError>

Encrypts and authenticates plaintext, returning the sequence number.

The resulting ciphertext is written to dst, which must be at least plaintext.len() + OVERHEAD bytes long.

pub fn seal_in_place( &mut self, data: impl AsMut<[u8]>, tag: &mut [u8], additional_data: &[u8], ) -> Result<Seq, HpkeError>

Encrypts and authenticates data in-place, returning the sequence number.

pub fn export<T>(&self, context: &[u8]) -> Result<T, KdfError>
where T: Expand,

Exports a secret from the encryption context.

pub fn export_into( &self, out: &mut [u8], context: &[u8], ) -> Result<(), KdfError>

Exports a secret from the encryption context, writing it to out.