pub struct SendCtx<K, F, A>{ /* private fields */ }Expand description
An encryption context that encrypts messages for a particular recipient.
Implementations
Sourceimpl<K, F, A> SendCtx<K, F, A>
impl<K, F, A> SendCtx<K, F, A>
Sourcepub const OVERHEAD: usize = SealCtx<A>::OVERHEAD
pub const OVERHEAD: usize = SealCtx<A>::OVERHEAD
The size in bytes of the overhead added to the plaintext.
Sourcepub fn seal(
&mut self,
dst: &mut [u8],
plaintext: &[u8],
additional_data: &[u8],
) -> Result<Seq, HpkeError>
pub fn seal( &mut self, dst: &mut [u8], plaintext: &[u8], additional_data: &[u8], ) -> Result<Seq, HpkeError>
Encrypts and authenticates plaintext, returning the
sequence number.
The resulting ciphertext is written to dst, which must
be at least plaintext.len() + OVERHEAD
bytes long.
Sourcepub fn seal_in_place(
&mut self,
data: impl AsMut<[u8]>,
tag: &mut [u8],
additional_data: &[u8],
) -> Result<Seq, HpkeError>
pub fn seal_in_place( &mut self, data: impl AsMut<[u8]>, tag: &mut [u8], additional_data: &[u8], ) -> Result<Seq, HpkeError>
Encrypts and authenticates data in-place, returning the
sequence number.